@@ -1,3 +1,6 @@
+from requests import Session
+
+from ..devices.gateway import Gateway
 from .property import Property, WrongElementError
 
 
@@ -5,14 +8,17 @@ class VoltageProperty(Property):
     """
     Object for voltages. It stores the current voltage and the corresponding unit.
 
+    :param gateway: Instance of a Gateway object
+    :param session: Instance of a requests.Session object
     :param element_uid: Element UID, something like devolo.VoltageMultiLevelSensor:hdm:ZWave:CBC56091/24
+    :param current: Voltage messured at the time of creating this instance
     """
 
-    def __init__(self, element_uid: str, current: float):
+    def __init__(self, gateway: Gateway, session: Session, element_uid: str, current: float):
         if not element_uid.startswith("devolo.VoltageMultiLevelSensor:"):
             raise WrongElementError(f"{element_uid} is not a Voltage Sensor.")
 
-        super().__init__(element_uid=element_uid)
+        super().__init__(gateway=gateway, session=session, element_uid=element_uid)
         self.current = current
         self.current_unit = "V"
 
@@ -23,6 +29,6 @@ class VoltageProperty(Property):
 
         :return: Voltage value
         """
-        response = self.mprm.get_data_from_uid_list([self.element_uid])
+        response = self.get_data_from_uid_list([self.element_uid])
         self.current = response.get("properties").get("value")
         return self.current
